@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11211 2018-08-26 06:08:08Z Lavender $
+# $Id: __init__.py 11219 2018-09-02 02:27:32Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-08-26 15:08:08 +0900 (週日, 26 八月 2018) $
-# $Revision: 11211 $
+# $Date: 2018-09-02 11:27:32 +0900 (週日, 02 九月 2018) $
+# $Revision: 11219 $
 
 from __future__ import print_function
 
@@ -840,7 +840,12 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     
     #=========================================================================
     # HAYSTACK
-    BASE_DIR = settingsDict['BASE_DIR']
+
+    if 'BASE_DIR' in settingsDict:
+        BASE_DIR = settingsDict['BASE_DIR']
+    else:
+        BASE_DIR = os.path.join(".")
+        
     if settingsDict['DEBUG'] or sys.platform.startswith("win32"):
         HAYSTACK_SETTINGS = {
             'HAYSTACK_CONNECTIONS': {
