@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11201 2018-08-12 14:45:23Z Lavender $
+# $Id: Util.py 11220 2018-09-02 04:29:45Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,18 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-08-12 23:45:23 +0900 (週日, 12 八月 2018) $
-# $Revision: 11201 $
+# $Date: 2018-09-02 13:29:45 +0900 (週日, 02 九月 2018) $
+# $Revision: 11220 $
 
+import sys
 import hashlib
 
 from collections import OrderedDict
-from urllib import urlencode
+
+if sys.version_info.major == 3:
+    from urllib.parse import urlencode
+else:
+    from urllib import urlencode
 
 # ​https://github.com/vinta/python-pay2go
 
