@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11206 2018-08-14 10:39:06Z Lavender $
+# $Id: __init__.py 11228 2018-09-18 13:29:34Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-08-14 19:39:06 +0900 (週二, 14 八月 2018) $
-# $Revision: 11206 $
+# $Date: 2018-09-18 22:29:34 +0900 (週二, 18 九月 2018) $
+# $Revision: 11228 $
 
 import os
 import sys
@@ -121,10 +121,13 @@ def attachSettings(settingsDict, enablePaypal=False):
         'django.contrib.sites',
         'django.contrib.flatpages',
         'widget_tweaks',
+    ) + tuple(get_core_apps(extraApps))
+    
+    ADDING_INSTALLED_APPS += (
         'Iuno.shop',
         'ckeditor',
         'ckeditor_uploader',
-    ) + tuple(get_core_apps(extraApps))
+    )
     
     ADDING_MIDDLEWARE_CLASSES = (
         'oscar.apps.basket.middleware.BasketMiddleware',
@@ -190,13 +193,27 @@ def attachSettings(settingsDict, enablePaypal=False):
     extendDatabaseDefaults(settingsDict, ADDING_DATABASES_DEFAULTS)
     #=========================================================================
     # Django haystack connections.
-    ADDING_HAYSTACK_CONNECTIONS = {
-        'HAYSTACK_CONNECTIONS' : {
-            'default': {
-                'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
+    BASE_DIR = settingsDict['BASE_DIR']
+    if settingsDict['DEBUG'] or sys.platform.startswith("win32"):
+        HAYSTACK_SETTINGS = {
+            'HAYSTACK_CONNECTIONS': {
+                'default': {
+                    'ENGINE': (
+                        'haystack.backends.whoosh_backend.WhooshEngine'),
+                    'PATH': os.path.join(BASE_DIR, 'whoosh_index'),
+                },
             },
         }
-    }
+    else:
+        HAYSTACK_SETTINGS = {
+            'HAYSTACK_CONNECTIONS': {
+                'default': {
+                    'ENGINE': 'xapian_backend.XapianEngine',
+                    'PATH': os.path.join(BASE_DIR, 'xapian_index'),
+                },
+            },
+        }
+        
     update(settingsDict, ADDING_HAYSTACK_CONNECTIONS)
     #=========================================================================
 
@@ -527,7 +544,7 @@ def buildAPIForm(submission, request, apiName):
             'MerchantID': settings.SPGATEWAY_API_MERCHANT_ID,
             'MerchantOrderNo': merchantTradeNo,
             'Amt': int(total),
-            'ItemDesc': itemName.replace('#', '\n'),
+            'ItemDesc': itemName.replace('#', '|'),
             'LoginType': 0,
             'CREDIT': 1,
             'UNIONPAY': 1,
